// VDCGenDlg.cpp : implementation file
//

#include "stdafx.h"
#include "VDCGen.h"
#include "VDCGenDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CVDCGenDlg dialog

CVDCGenDlg::CVDCGenDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CVDCGenDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CVDCGenDlg)
		// NOTE: the ClassWizard will add member initialization here
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CVDCGenDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CVDCGenDlg)
	DDX_Control(pDX, IDC_STOP, m_stop);
	DDX_Control(pDX, IDC_START, m_start);
	DDX_Control(pDX, IDC_OPEN, m_open);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CVDCGenDlg, CDialog)
	//{{AFX_MSG_MAP(CVDCGenDlg)
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_OPEN, OnOpen)
	ON_BN_CLICKED(IDC_START, OnStart)
	ON_BN_CLICKED(IDC_STOP, OnStop)
	ON_WM_CLOSE()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CVDCGenDlg message handlers

BOOL CVDCGenDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// TODO: Add extra initialization here

	m_driverInstance=NULL;
	m_pSR=NULL;   // set our pointers equal to something
	
	return TRUE;  // return TRUE  unless you set the focus to a control
}

// If you add a minimize button to your dialog, you will need the code below
//  to draw the icon.  For MFC applications using the document/view model,
//  this is automatically done for you by the framework.

void CVDCGenDlg::OnPaint() 
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, (WPARAM) dc.GetSafeHdc(), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialog::OnPaint();
	}
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CVDCGenDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}

void CVDCGenDlg::OnOpen() 
{
	// open the driver.  Pass in name of driver to avoid the OpenDriverLINX dialog
	// use kmbctm for CTM boards, kpci3140 for KPCI-4140, kpci3100 for KPCI-3101, etc
	m_driverInstance=OpenDriverLINX(m_hWnd,"kmbctm");
	// now allocate our structure and init all members to zero
	m_pSR=(DL_ServiceRequest *)new DL_ServiceRequest;
	memset(m_pSR,0,sizeof(DL_ServiceRequest));
	DL_SetServiceRequestSize(*m_pSR);
	// now initialize the hardware with an INITIALIZE operation on the DEVICE
	m_pSR->operation=INITIALIZE;
	m_pSR->device=0;     // device number should agree with DLinx Config Panel
	m_pSR->subsystem=DEVICE;
	m_pSR->hWnd=m_hWnd;   // could pass desk top handle if making a console app
	m_pSR->mode=OTHER;
	DriverLINX(m_pSR);   // carry out the task
	showMessage(m_pSR);  // do a message box operation to check for problems

	CWnd::SetActiveWindow();  // set focus back to our dialog

	m_open.EnableWindow(FALSE);
	m_start.EnableWindow(TRUE);
}

void CVDCGenDlg::OnStart() 
{
// set up the task to START a Variable Duty Cycle
	m_pSR->operation=START;
	m_pSR->subsystem=CT;
	m_pSR->mode=POLLED;
	m_pSR->start.typeEvent=COMMAND;
	m_pSR->timing.typeEvent=RATEEVENT;
	m_pSR->stop.typeEvent=COMMAND;
	m_pSR->timing.u.rateEvent.channel=0;  // will be CT0
	m_pSR->timing.u.rateEvent.mode=VDCGEN;  
	m_pSR->timing.u.rateEvent.pulses=0;
	m_pSR->timing.u.rateEvent.clock=INTERNAL1;
	m_pSR->timing.u.rateEvent.period=Sec2Tics(0,CT,INTERNAL1,1);  // one second total period
	m_pSR->timing.u.rateEvent.onCount=Sec2Tics(0,CT,INTERNAL1,0.1f);  // 100 msec on time
	m_pSR->timing.u.rateEvent.gate= HILEVELGATEN;  // gate must be logic 1 for VDC to occur
	DriverLINX(m_pSR);   // start the task
	showMessage(m_pSR);  // check for error

	m_start.EnableWindow(FALSE);
	m_stop.EnableWindow(TRUE);

	/*
    This application was tested with a CTM-05/A in Win98SE using
	CTM-850A01.0.0.2 version of DriverLINX

    In the DriverLINX Configuration Panel, the timebase resolution is set
	for 1.0 MHz and the Freq Scaler is BCD.

    DriverLINX implementation for CTM will automatically select one of the 
	slower timebases (Internal2....Internal5) rather than stick with the
	Internal1 (1MHz) to accomplish the requested durations.

    See the the App Note on web site regarding the limits on signals generated
	with a CTM based upon the various settings.

  */
	
}

void CVDCGenDlg::OnStop() 
{
	// stop the task
	m_pSR->operation=STOP;
	DriverLINX(m_pSR);
	showMessage(m_pSR);

	m_start.EnableWindow(TRUE);
	m_stop.EnableWindow(FALSE);
	
}

void CVDCGenDlg::OnClose() 
{
	// close the driver and free up the memory used by the structure
    if (m_driverInstance != NULL)
	{
	    CloseDriverLINX(m_driverInstance);
	    m_driverInstance=NULL;
	}
	if (m_pSR != NULL)
	{
	   delete m_pSR;
	   m_pSR=NULL;
	}

	// pass the message on up the class
	CDialog::OnClose();
}

void CVDCGenDlg::showMessage(DL_ServiceRequest *SR)
{
	if(SR->result != NoErr)
	{
		SR->operation=MESSAGEBOX;
		DriverLINX(SR);
	}

}


